#undef	ENABLE_NLS
#undef	HAVE_CATGETS
#undef	HAVE_GETTEXT
#undef	HAVE_LC_MESSAGES
#undef	HAVE_STPCPY
#undef	HAVE_WAIT4
#undef	HAVE_LIBSM

/* build for the GNOME desktop project ?
 */
#undef	GNOMIFY

#undef	PACKAGE
#undef	LIBGLE_MAJOR
#undef	LIBGLE_REVISION
#undef	LIBGLE_PATCHLEVEL
#undef	LIBGLE_AGE
#undef	LIBGLE_VERSION
#undef	VERSION

#undef	GLE_WORKS_WITH_GTK_VERSION

@BOTTOM@
/* general defines
 */
#define	GLE_FLASH_MSEC		(333)
#define	GLE_PRIVATE_KEY(key)	"__gle-private-data__-" #key
#define	GLE_GARGS_PREALLOC	(512)
#define	GLE_GOBJECTS_PREALLOC	(16)
#define	GLE_GWIDGETS_PREALLOC	(64)
#define	DMALLOG
